@@ -17,8 +17,9 @@ class Query():
         self.reader = connection.reader
         self.writer = connection.writer
         
-    async def do_query(protocol : typing.Union[Get, Set]):
-        self.writer.write(protocol.query.encode())
+    async def do_query(self, protocol : typing.Union[Get, Set]):
+        data_ = protocol.query+"\r\n"
+        self.writer.write(data.encode())
         await self.writer.drain()
         data = await self.reader.read(100)
         return Result(f'{data.decode()!r}')
